@@ -20,6 +20,7 @@
 #' }
 #'
 #' @examples
+#' \dontrun{
 #' ## generate swiss roll data
 #' X = aux.gensamples(n=123)
 #'
@@ -33,6 +34,7 @@
 #' plot(out1$Y[,1], out1$Y[,2], main="ASI::tol=1e-2")
 #' plot(out2$Y[,1], out2$Y[,2], main="ASI::tol=1e-3")
 #' plot(out3$Y[,1], out3$Y[,2], main="ASI::tol=1e-4")
+#' }
 #'
 #' @references
 #' \insertRef{li_document_2004}{Rdimtools}
@@ -83,8 +85,8 @@ do.asi <- function(X, ndim=2, preprocess=c("center","decorrelate","whiten"), max
     pXkmeans  = kmeans(projected, k)
     # 3-2. LDA-KM(2) : learn again
     # 1. build H
-    H = ldakm_BuildH(pXkmeans$cluster)       # H : (n-times-k)
-    M = t(pX)%*%H%*%pracma::pinv(t(H)%*%H)   # M : (p-times-k)
+    H = ldakm_BuildH(pXkmeans$cluster)     # H : (n-times-k)
+    M = (t(pX)%*%H%*%aux.pinv(t(H)%*%H))   # M : (p-times-k)
     # 2. build Sw (p-by-p)
     Swterm1 = t(pX)-(M%*%t(H))
     Sw = Swterm1%*%t(Swterm1)
